/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.shopping.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Product.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Search API For Shopping. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Product extends GenericJson {

  /**
   * List of categories for product.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<ShoppingModelCategoryJsonV1> categories;

  static {
    // hack to force ProGuard to consider ShoppingModelCategoryJsonV1 used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(ShoppingModelCategoryJsonV1.class);
  }

  /**
   * Google internal.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ShoppingModelDebugJsonV1 debug;

  /**
   * Id of product.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of item, always shopping#product.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Product.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ShoppingModelProductJsonV1 product;

  /**
   * Recommendations for product.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<ShoppingModelRecommendationsJsonV1> recommendations;

  static {
    // hack to force ProGuard to consider ShoppingModelRecommendationsJsonV1 used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(ShoppingModelRecommendationsJsonV1.class);
  }

  /**
   * Unique identifier for this request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String requestId;

  /**
   * Self link of product when generated for a lookup request. Self link of product when generated
   * for a search request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * List of categories for product.
   * The value returned may be {@code null}.
   */
  public java.util.List<ShoppingModelCategoryJsonV1> getCategories() {
    return categories;
  }

  /**
   * List of categories for product.
   * The value set may be {@code null}.
   */
  public Product setCategories(java.util.List<ShoppingModelCategoryJsonV1> categories) {
    this.categories = categories;
    return this;
  }

  /**
   * Google internal.
   * The value returned may be {@code null}.
   */
  public ShoppingModelDebugJsonV1 getDebug() {
    return debug;
  }

  /**
   * Google internal.
   * The value set may be {@code null}.
   */
  public Product setDebug(ShoppingModelDebugJsonV1 debug) {
    this.debug = debug;
    return this;
  }

  /**
   * Id of product.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Id of product.
   * The value set may be {@code null}.
   */
  public Product setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of item, always shopping#product.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of item, always shopping#product.
   * The value set may be {@code null}.
   */
  public Product setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Product.
   * The value returned may be {@code null}.
   */
  public ShoppingModelProductJsonV1 getProduct() {
    return product;
  }

  /**
   * Product.
   * The value set may be {@code null}.
   */
  public Product setProduct(ShoppingModelProductJsonV1 product) {
    this.product = product;
    return this;
  }

  /**
   * Recommendations for product.
   * The value returned may be {@code null}.
   */
  public java.util.List<ShoppingModelRecommendationsJsonV1> getRecommendations() {
    return recommendations;
  }

  /**
   * Recommendations for product.
   * The value set may be {@code null}.
   */
  public Product setRecommendations(java.util.List<ShoppingModelRecommendationsJsonV1> recommendations) {
    this.recommendations = recommendations;
    return this;
  }

  /**
   * Unique identifier for this request.
   * The value returned may be {@code null}.
   */
  public String getRequestId() {
    return requestId;
  }

  /**
   * Unique identifier for this request.
   * The value set may be {@code null}.
   */
  public Product setRequestId(String requestId) {
    this.requestId = requestId;
    return this;
  }

  /**
   * Self link of product when generated for a lookup request. Self link of product when generated
   * for a search request.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * Self link of product when generated for a lookup request. Self link of product when generated
   * for a search request.
   * The value set may be {@code null}.
   */
  public Product setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

}
